What’s new in version 1.1.9
===========================
Version available since November 10th 2022


New Features
------------

- In ode_tools file, a new function "integrale" was created to compute integrales with their gradients.
- Normalization of inputs before optimization, to help algorithm to converge.


Contributors
------------
Lucas Agobert
